<?php
/**
 * Plugin Name: AI Content Assistant
 * Plugin URI: 
 * Description: Helps analyze and improve content using various AI assistants
 * Version: 1.0.0
 * Author: Robert Wallace
 * License: GPL v2 or later
 * Text Domain: ai-content-assistant
 */

if (!defined('ABSPATH')) {
    exit;
}

class AI_Content_Assistant {
    
    private $ai_providers = array(
        'claude' => array(
            'name' => 'Claude',
            'url' => 'https://claude.ai'
        ),
        'chatgpt' => array(
            'name' => 'ChatGPT',
            'url' => 'https://chat.openai.com'
        ),
        'bard' => array(
            'name' => 'Bard',
            'url' => 'https://bard.google.com'
        )
    );
    
    public function __construct() {
        add_action('init', array($this, 'init'));
        add_action('admin_menu', array($this, 'add_settings_page'));
        add_action('admin_init', array($this, 'register_settings'));
    }

    public function init() {
        add_action('enqueue_block_editor_assets', array($this, 'enqueue_block_editor_assets'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_classic_editor_assets'));
    }

    public function add_settings_page() {
        add_options_page(
            'AI Content Assistant Settings',
            'AI Content Assistant',
            'manage_options',
            'ai-content-assistant',
            array($this, 'render_settings_page')
        );
    }

    public function register_settings() {
        register_setting('ai-content-assistant', 'ai_content_default_provider');
        register_setting('ai-content-assistant', 'ai_content_default_prompts');
    }

    public function render_settings_page() {
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form action="options.php" method="post">
                <?php
                settings_fields('ai-content-assistant');
                do_settings_sections('ai-content-assistant');
                ?>
                <table class="form-table">
                    <tr>
                        <th scope="row">
                            <label for="ai_content_default_provider">Default AI Provider</label>
                        </th>
                        <td>
                            <select name="ai_content_default_provider" id="ai_content_default_provider">
                                <?php foreach ($this->ai_providers as $key => $provider): ?>
                                    <option value="<?php echo esc_attr($key); ?>" <?php selected(get_option('ai_content_default_provider'), $key); ?>>
                                        <?php echo esc_html($provider['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="ai_content_default_prompts">Default Prompts</label>
                        </th>
                        <td>
                            <textarea name="ai_content_default_prompts" id="ai_content_default_prompts" rows="10" class="large-text"><?php echo esc_textarea(get_option('ai_content_default_prompts', "Analyze this content\nWrite a conclusion\nSuggest improvements\nMake more engaging")); ?></textarea>
                            <p class="description">Enter one prompt per line. These will appear as quick-access buttons.</p>
                        </td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    public function enqueue_block_editor_assets() {
        wp_enqueue_script(
            'ai-content-assistant',
            plugins_url('js/block-editor.js', __FILE__),
            array('wp-blocks', 'wp-element', 'wp-editor', 'wp-components', 'wp-i18n', 'wp-plugins', 'wp-edit-post', 'wp-data'),
            filemtime(plugin_dir_path(__FILE__) . 'js/block-editor.js'),
            true
        );

        wp_localize_script(
            'ai-content-assistant',
            'aiContentAssistant',
            array(
                'providers' => $this->ai_providers,
                'defaultProvider' => get_option('ai_content_default_provider', 'claude'),
                'defaultPrompts' => explode("\n", get_option('ai_content_default_prompts', "Analyze this content\nWrite a conclusion\nSuggest improvements\nMake more engaging"))
            )
        );

        wp_enqueue_style(
            'ai-content-assistant',
            plugins_url('css/styles.css', __FILE__),
            array(),
            filemtime(plugin_dir_path(__FILE__) . 'css/styles.css')
        );
    }

    public function enqueue_classic_editor_assets($hook) {
        if (!in_array($hook, array('post.php', 'post-new.php'))) {
            return;
        }

        wp_enqueue_script(
            'ai-content-assistant',
            plugins_url('js/classic-editor.js', __FILE__),
            array('jquery'),
            filemtime(plugin_dir_path(__FILE__) . 'js/classic-editor.js'),
            true
        );

        wp_localize_script(
            'ai-content-assistant',
            'aiContentAssistant',
            array(
                'providers' => $this->ai_providers,
                'defaultProvider' => get_option('ai_content_default_provider', 'claude'),
                'defaultPrompts' => explode("\n", get_option('ai_content_default_prompts', "Analyze this content\nWrite a conclusion\nSuggest improvements\nMake more engaging"))
            )
        );

        wp_enqueue_style(
            'ai-content-assistant',
            plugins_url('css/styles.css', __FILE__),
            array(),
            filemtime(plugin_dir_path(__FILE__) . 'css/styles.css')
        );
    }
}

new AI_Content_Assistant();